% analyseMarkerAngularErrorWhenStatic
%
% Check the behaviour or marker with respect to angulation due to 
% noise in the fiducial measurement.
% Express the result as the spread of the rodrigues vector representing
% the noisy rotation vector
%
% Assume that the marker points are defined in a plane z = cst.
% geometry: 3 x n array of double
%         each column represents the x,y,z coordinates of a fiducial in mm
% z: z distance in mm where the analysis should take place.
% error: fiducial localization error at position z

function analyseMarkerAngularErrorWhenStatic (geometry, z, error)

    samples=1e3;
    rodriguesErrors = zeros(3,samples); 
    
    % Project geometry in device referential
    points = eye(3) * geometry + repmat ([0;0;z],1,size(geometry,2));
     
    for i=1:samples
        % Simulate error on the points (FLE)
        measuredPointsWithNoise = markerAddNoise (points, error);
        % Compute the marker registration
        [Rot, ~, ~] = markerRegistration(points, measuredPointsWithNoise);
        % Express the rotation as a rodrigues vector
        rodriguesErrors(:,i) = rodrigues(Rot);
    end
    
    stdError = std(rodriguesErrors')';
    meanError = mean(rodriguesErrors')';
    %rmse = sqrt( meanError.^2 + stdError.^2 )
    rmsError = rms(rodriguesErrors')';
    
    displayMatrix([meanError, stdError, rmsError], {'rodrigues_x','rodrigues_y','rodrigues_z'}, {'mean', 'std','rms'});

end
