function [ranges] = computeRanges(values, rangeSize)
% computeRanges computes a range of size rangeSize around a given 
% set of values. 
% values: 1 x n double
%         ascending order compulsory
% rangeSize: double
% returns: struct array
%          every element has the fields 'lower' and 'upper'
%
% The ranges are computed using +/- rangeSize/2. If ranges overlap, 
% they are merged.

    nbRanges = 1;
    ranges(1) = struct('lower', values(1) - (rangeSize / 2), 'upper', values(1) + (rangeSize / 2));
    for i=2:size(values,2)
        if(ranges(nbRanges).upper < (values(i) - (rangeSize / 2)))
            nbRanges = nbRanges + 1;
            ranges(nbRanges) = struct('lower', values(i) - (rangeSize / 2), 'upper', values(i) + (rangeSize / 2));
        else
            ranges(nbRanges).upper = values(i) + (rangeSize / 2);
        end
    end
end

