function [ distanceMaps ] = computeTriangleDistanceMaps(triangles, segmentLengthMatrix)
% computeTriangleDistanceMaps computes triangle distance maps
% triangles: struct array
%            required fields: 'point1Idx', 'point2Idx' and 'point3Idx'
% segmentLengthMatrix: n x n double
%                      The segment lengths in matrix form
% returns: struct array
%          each element has the fields 'triangleIdx', 'pointIdx',
%          'distance1', 'distance2' and 'oppositeSegmentLength'

    for i=1:size(triangles, 2)
        for j=1:3
            if j == 1
                pointIdx = triangles(i).point1Idx;
                distances = [segmentLengthMatrix(triangles(i).point1Idx, triangles(i).point2Idx) segmentLengthMatrix(triangles(i).point1Idx, triangles(i).point3Idx)];
                oppositeSegmentLength = segmentLengthMatrix(triangles(i).point2Idx, triangles(i).point3Idx);
            end
            if j == 2
                pointIdx = triangles(i).point2Idx;
                distances = [segmentLengthMatrix(triangles(i).point1Idx, triangles(i).point2Idx) segmentLengthMatrix(triangles(i).point2Idx, triangles(i).point3Idx)]; 
                oppositeSegmentLength = segmentLengthMatrix(triangles(i).point1Idx, triangles(i).point3Idx);
            end
            if j == 3
                pointIdx = triangles(i).point3Idx;
                distances = [segmentLengthMatrix(triangles(i).point1Idx, triangles(i).point3Idx) segmentLengthMatrix(triangles(i).point2Idx, triangles(i).point3Idx)]; 
                oppositeSegmentLength = segmentLengthMatrix(triangles(i).point1Idx, triangles(i).point2Idx);
            end
            distanceMaps((i - 1) * 3 + j) = struct('triangleIdx', i, 'pointIdx', pointIdx, 'distance1', min(distances), 'distance2', max(distances), 'oppositeSegmentLength', oppositeSegmentLength);
        end
    end
end

