function [triangles] = computeTriangles(segmentLengthMatrix)
% computeTriangles computes the data for all triangles deduced from the 
% segment length matrix
% segmentLengthMatrix: n x n double
%                      The segment lengths in matrix form
% returns: struct array
%          each element has the fields 'point1Idx', 'point2Idx',
%          'point3Idx', 'point1Angle', 'point2Angle', 'point3Angle' and
%          'surface'

    nbPts = size(segmentLengthMatrix, 1);
    triangleIdx = 1;
    for i=1:nbPts
        for j=i+1:nbPts
            for k=j+1:nbPts
                [alpha, beta, gamma] = computeTriangleAngles(segmentLengthMatrix(j, k), segmentLengthMatrix(i, k), segmentLengthMatrix(i, j));
                triangles(triangleIdx) = struct('point1Idx', i, 'point2Idx', j, 'point3Idx', k, 'point1Angle', alpha, 'point2Angle', beta, 'point3Angle', gamma, 'surface', computeTriangleSurface(segmentLengthMatrix(i, j), segmentLengthMatrix(j, k), segmentLengthMatrix(k, i)));
                triangleIdx = triangleIdx + 1;
            end
        end
    end
end