function [] = displayMatrix(data, rowLabels, columnLabels)
% displayMatrix show a matrix with labelled rows & cols
% data: n x n double or struct array
% rowLabels: n x 1 cell array or 1 x n cell array or a char array 
%            if it is a string, it should be the pattern to use
%            for every row. F.ex. 'point %i' gives 'point 1', 
%            'point 2', ..., 'point n' as row labels
% columnLabels: 1 x n cell array or a char array. if it is a string, 
%               it should be the pattern to use for every column. 
%               F.ex. 'point %i' gives 'point 1', 'point 2', ..., 
%               'point n' as column labels
% returns: -
%
% Unlike matlabs native dispmat() function, numeric data is not
% re-formatted to 6 digit floats which usually takes a lot less space.

    if isstruct(data)
        data = permute(squeeze(struct2cell(data)), [2 1]);
    else
        data = num2cell(data);
    end
    
    if size(rowLabels, 2) > 1
        rowLabels = rowLabels';
    end
    
    nbRows = size(data, 1);
    if ischar(rowLabels)
        rowLabelPattern = rowLabels;
        rowLabels = cell(nbRows, 1);
        for i=1:nbRows
            rowLabels{i} = sprintf(rowLabelPattern, i);
        end
    end
    
    nbCols = size(data, 2);
    if ischar(columnLabels)
        columnLabelPattern = columnLabels;
        columnLabels = cell(1, nbCols);
        for i=1:nbCols
            columnLabels{i} = sprintf(columnLabelPattern, i);
        end
    end
    
    disp(horzcat([{''}; rowLabels],[columnLabels; data]));
end

