 function retval = generateReports()

  % Load configuration
  currentDir = fileparts(mfilename('fullpath'));

  if isunix || ismac
      configFile = sprintf('%s/%s', currentDir, 'reportingCfg.m');
  else
      configFile = sprintf('%s\\%s', currentDir, 'reportingCfg.m');
  end

  if exist (configFile, 'file') ~= 2
      error ('Invalid configuration file (%s)',configFile);
  end

  run(configFile);

  if exist (inputFolder,'dir') ~= 7
      error ('Invalid input folder (%s) specified in reportingCfg.m',inputFolder);
  end

  if exist (outputFolder,'dir') ~= 7
      error ('Invalid output folder (%s) specified in reportingCfg.m',outputFolder);
  end

  if ( exist('OCTAVE_VERSION', 'builtin') ~= 0 )
      warning('off', 'Octave:possible-matlab-short-circuit-operator');
  end

  if ( exist('OCTAVE_VERSION', 'builtin') == 0 )
    state = recycle('on');
  end

  if exist(sprintf('%s/geometry*.txt', outputFolder), 'file')==2
    delete(sprintf('%s/geometry*.txt', outputFolder));
  end

  if exist(sprintf('%s/marker combination report.txt', outputFolder), 'file')==2
    delete(sprintf('%s/marker combination report.txt', outputFolder));
  end

  if exist(sprintf('%s/summary.txt', outputFolder), 'file')==2
    delete(sprintf('%s/summary.txt', outputFolder));
  end

  if exist(sprintf('%s/*angular analysis.jpg', outputFolder), 'file')==2
    delete(sprintf('%s/*angular analysis.jpg', outputFolder));
  end

  if ( exist('OCTAVE_VERSION', 'builtin') == 0 )
    recycle (state);
  end

  % Check input folder
  list = dir(inputFolder);
  list([list.isdir]) = [];

  clc;

  markers = struct('points', [], 'name', []);
  markerResults = struct('id', [], 'name', [], 'nbPbs', [], 'filename', []);
  markerIdx = 0;
  for i=1:length(list)
      inifile = list(i).name;
      % get file details & ignore everything else than *.ini
      [pathstr, filename, extension] = fileparts(inifile);
      if strcmp(strtrim(extension), '.ini') ~= 1
          continue;
      end

      % load marker data
      [markerId, points] = loadMarkerIniFile(sprintf('%s%s', inputFolder, inifile));
      markerName = getMarkerName(markerId);

      % run marker analysis + store into struct array for combination test
      markerIdx = markerIdx + 1;
      if analyzeMarkers
          nbPbs = generateMarkerReport(points, threshold, sprintf('%s%s.txt', outputFolder, filename), markerName, showMarkerPlots);
          markerResults(markerIdx) = struct('id', markerId, 'name', markerName, 'nbPbs', nbPbs, 'filename', sprintf('%s%s.txt', outputFolder, filename));
      end
      if analyzeMarkerCombination
          markers(markerIdx) = struct('points', points, 'name', markerName);
      end
  end

  if markerIdx == 0
      warning ('No marker detected in input folder (%s)',inputFolder);
  end

  % run marker combination analysis
  if analyzeMarkerCombination && markerIdx > 0
      nbCombinationPbs = generateMarkerCombinationReport(markers, threshold, sprintf('%smarker combination report.txt', outputFolder));
  end

  diary(sprintf('%s/summary.txt', outputFolder));
  diary on;
  disp('*************** Atracsys marker analysis summary ***************');
  totalNbPbs = 0;
  if analyzeMarkers
      disp('Analyzed markers:');
      for i=1:size(markerResults, 2)
          totalNbPbs = totalNbPbs + markerResults(i).nbPbs;
          fprintf('- "%s" (ID %i): %i problem(s) detected\n', markerResults(i).name,  markerResults(i).id,  markerResults(i).nbPbs);
          fprintf('  report saved to %s \n', markerResults(i).filename);
      end
  end
  if analyzeMarkerCombination
      fprintf('\nMarker combination: %i problem(s) detected\n', nbCombinationPbs);
      fprintf('report saved to %s \n', sprintf('%smarker combination report.txt', outputFolder));
  end
  if totalNbPbs + nbCombinationPbs == 0
      fprintf('\nResult: analyzed marker input is valid');
  else
      fprintf('\nResult: analyzed marker input is not valid');
  end
  fprintf('\n\n');

  diary off;

  if totalNbPbs + nbCombinationPbs == 0
    retval = 0
  else
    retval = 1
  end
end
