% computeMarker 
% Compute the marker registration and error given two pointset 
% using ARUN method.
% Input
% M: first dataset
% S: second dataset
% Return
% R: Resulting rotation matrix
% t: Resulting translation vector
% Error: registration error

function [R, t, Error] = markerRegistration (M, S)

    function arun_registration(X,Y)
        if (size (X) ~= size (Y))
        error ('Dimension of datasets do not agree');
        end

        s = size (X, 2);

        % solve for position
        Ymean = mean(Y')';
        Xmean = mean(X')';
        K = (Y - Ymean*ones(s,1)')*(X - Xmean*ones(s,1)')';
        [U,~,V] = svd(K);
        D = eye(3,3);
        D(3,3) = det(U*V');
        R = U*D*V';
        t = Ymean - R*Xmean;
        
        clear s Ymean Xmean K U V D;
        % Registration result in local variables R and t
    end

    if nargin < 2,
        error('Need two input arguments'); 
    end;

    arun_registration (M, S); % R and t variables set by sub-function

    Mh = [M; ones(1,size(M,2))];
    Sh = [S; ones(1,size(S,2))];
    H =  [R t; 0 0 0 1];

    Mph    = H^-1 * Sh;
    Errorh = Mph - Mh;
    Error  = mean (sqrt (Errorh(1,:).^2 + Errorh(2,:).^2 + Errorh(3,:).^2));
    
end