function [h] = plotSegmentLengthDistribution(segmentLengths, threshold, showPlots)
% plotSegmentLengthDistribution plot a gaussian for an array of segment
% lengths
% segment lengths: n x 1 double
% threshold: double
%            used as sigma in for the gaussians
% returns: figure handle

    nbSegments = size(segmentLengths, 2);
    if showPlots == 1
        h = figure;
    else
        h = figure('visible', 'off');
    end
    colormap = lines(nbSegments);
    x = 0:0.2:(max(segmentLengths) + 20);
    hold on;
    for i=1:nbSegments
        y = gaussmf(x, [threshold segmentLengths(i)]);
        plot(x, y, '.', 'color', colormap(i, :));
    end
    hold off;
    grid on;
    title('Segment length distribution');
    xlabel('Length');
    ylabel('Gauss distribution');
end

